==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-config-session/lxqt-config-session_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komando:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Atendado de sistempleto</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Elektu aplikaĵon</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Ĉiea aŭtomata starto</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>Aŭtomata starto de LXQto</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Loko: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Ĝi anstataŭigas: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Aŭtomata startigo de aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Dosiero &apos;%1&apos; jam ekzistas!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Fenestra mastrumilo</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished">Moduloj de LXQto</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Bazaj agordoj</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>Elektu fenestran mastrumilon</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Elektu simulilon de terminalo</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Elektu retumilon</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Aprioraj aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Simulilo de terminalo:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Retumilo:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ĉirkaŭaĵaj variabloj (progresinta)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nomo de variablo</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valoro</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LXQt Session Configuration</source>
        <translation type="vanished">Agordoj de seanco de LXQt</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Bazaj agordoj</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Aprioraj aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Aŭtomata startigo</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Ĉirkaŭaĵo (progresinta)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Postulata restartigo de seanco</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Vi devas restartigi la seancon de labortablo (lxqt-session) por reŝargi agordojn. Uzu ensaluton en la ĉefa menuo.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-config-session/lxqt-config-session_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komando:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Atendado de sistempleto</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Elektu aplikaĵon</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Ĉiea aŭtomata starto</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>Aŭtomata starto de LXQto</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Loko: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Ĝi anstataŭigas: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Aŭtomata startigo de aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Dosiero &apos;%1&apos; jam ekzistas!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Fenestra mastrumilo</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished">Moduloj de LXQto</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Bazaj agordoj</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="146"/>
        <source>Select a window manager</source>
        <translation>Elektu fenestran mastrumilon</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Elektu simulilon de terminalo</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Elektu retumilon</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Aprioraj aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Simulilo de terminalo:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Serĉi...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Retumilo:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Ĉirkaŭaĵaj variabloj (progresinta)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nomo de variablo</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valoro</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LXQt Session Configuration</source>
        <translation type="vanished">Agordoj de seanco de LXQt</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Bazaj agordoj</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Aprioraj aplikaĵoj</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Aŭtomata startigo</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Ĉirkaŭaĵo (progresinta)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Postulata restartigo de seanco</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Vi devas restartigi la seancon de labortablo (lxqt-session) por reŝargi agordojn. Uzu ensaluton en la ĉefa menuo.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
